@@ -1,6 +1,3 @@
-# -*- coding=utf-8 -*-
-from __future__ import absolute_import, print_function
-
 import logging
 import os
 import sys
@@ -14,12 +11,13 @@ from pip._internal.commands.install import InstallCommand
 from pip._internal.models.target_python import TargetPython
 from pip._internal.utils.filetypes import is_archive_file
 from pip._internal.utils.misc import is_installable_dir
+from pip._vendor.packaging import specifiers
 from vistir.path import ensure_mkdir_p, is_valid_url
 
 from .environment import MYPY_RUNNING
 
 if MYPY_RUNNING:
-    from typing import Any, Dict, Iterable, List, Optional, Text, Tuple, TypeVar, Union
+    from typing import Dict, List, Optional, Text, Tuple, TypeVar, Union
 
     STRING_TYPE = Union[bytes, str, Text]
     S = TypeVar("S", bytes, str, Text)
@@ -159,7 +157,6 @@ def convert_entry_to_path(path):
 def is_installable_file(path):
     # type: (PipfileType) -> bool
     """Determine if a path can potentially be installed."""
-    from packaging import specifiers
 
     if isinstance(path, Mapping):
         path = convert_entry_to_path(path)
@@ -203,11 +200,9 @@ def is_installable_file(path):
 def get_dist_metadata(dist):
     from email.parser import FeedParser
 
-    import pkg_resources
+    from pip._vendor.pkg_resources import DistInfoDistribution
 
-    if isinstance(dist, pkg_resources.DistInfoDistribution) and dist.has_metadata(
-        "METADATA"
-    ):
+    if isinstance(dist, DistInfoDistribution) and dist.has_metadata("METADATA"):
         metadata = dist.get_metadata("METADATA")
     elif dist.has_metadata("PKG-INFO"):
         metadata = dist.get_metadata("PKG-INFO")
